@@ -1,6 +1,6 @@
-#define BYTE            1
-#define SHORT           2
-#define LONG            4
+#define TP_BYTE         1
+#define TP_WORD         2
+#define TP_LONG         4
 
 #define TRUE            1
 #define FALSE           0
@@ -22,6 +22,10 @@
 #define ATHLONPM_LIST	B8(00001000)
 #define ATHLONPM_FIXUP  B8(00010000)
 
+#define BYTE_t u8 // uint8_t
+#define WORD_t u16 //uint16_t
+#define LONG_t u32 //uint32_t
+
 struct device
 {
   struct device	*next;
